==> nextcloud-15.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/th.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "แกลอรี่",
    "There was a problem reading files from this album" : "เกิดปัญหาการอ่านไฟล์จากอัลบั้มนี้",
    "Aborting preview. Could not find the file" : "กำลังยกเลิกการแสดงตัวอย่าง ไม่สามารถค้นหาไฟล์",
    "Could not move \"{file}\", target exists" : "ไม่สามารถย้ายไฟล์ \"{file}\" ไม่มีไฟล์นั้นอยู่",
    "Could not move \"{file}\"" : "ไม่สามารถย้ายไฟล์ \"{file}\"",
    "Could not load the description" : "ไม่สามารถโหลดคำอธิบาย",
    "Could not load the description: " : "ไม่สามารถโหลดคำอธิบาย",
    "Copyright" : "ลิขสิทธิ์",
    "Could not load the copyright notice: " : "โปรดทราบไม่สามารถโหลดลิขสิทธิ์:",
    "Copyright notice" : "โปรดทราบเรื่องลิขสิทธิ์",
    "Link to copyright document" : "เชื่อมโยงไปยังเอกสารลิขสิทธิ์",
    "This application may not work properly on your browser." : "แอพฯนี้อาจทำงานผิดพลาดในเบราว์เซอร์ของคุณ",
    "For an improved experience, please install one of the following alternatives" : "เพื่อทางที่ดีขึ้นโปรดติดตั้งหนึ่งในทางเลือกดังต่อไปนี้",
    "Your browser is not supported!" : "เบราว์เซอร์ของคุณไม่ได้รับการสนับสนุน!",
    "please install one of the following alternatives" : "โปรดติดตั้งหนึ่งในทางเลือกดังต่อไปนี้",
    "Album cannot be shown" : "ไม่สามารถแสดงอัลบั้มได้",
    "No media files found" : "ไม่พบไฟล์สื่อ",
    "Upload new files via drag and drop or by using the [+] button above" : "อัพโหลดไฟล์ใหม่ผ่านการลากและวางหรือโดยการใช้ปุ่ม [+] ดังกล่าวข้างต้น",
    "Configuration error" : "กำหนดค่าผิดพลาด",
    "Hide Album" : "ซ่อนอัลบั้ม",
    "Could not hide album" : "ไม่สามารถซ่อนอัลบั้ม",
    "Error loading slideshow template" : "เกิดข้อผิดพลาดในการโหลดเทมเพลตสไลด์โชว์",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>ข้อผิดพลาด!</strong> ไม่สามารถสร้างตัวอย่างการแสดงของไฟล์นี้<br> โปรดไปยังภาพนิ่งถัดไปในขณะที่เราลบภาพนี้จากสไลด์โชว์",
    "Next" : "ถัดไป",
    "Play" : "เล่น",
    "Pause" : "หยุดชั่วคราว",
    "Previous" : "ก่อนหน้า",
    "Close" : "ปิด",
    "Download" : "ดาวน์โหลด",
    "Toggle background" : "สลับพื้นหลัง",
    "Delete" : "ลบ",
    "Share" : "แชร์",
    "Could not create file \"{file}\" because it already exists" : "ไม่สามารถสร้างไฟล์ \"{file}\" เพราะมันมีอยู่แล้ว",
    "Could not create file \"{file}\"" : "ไม่สามารถสร้างไฟล์ \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" เป็นชื่อไฟล์ที่ไม่ถูกต้อง",
    "File name cannot be empty." : "ชื่อไฟล์ไม่สามารถเว้นว่างได้",
    "Upload" : "อัพโหลด",
    "Error" : "ข้อผิดพลาด",
    "Error while sharing" : "เกิดข้อผิดพลาดขณะกำลังแชร์ข้อมูล",
    "Error while unsharing" : "เกิดข้อผิดพลาดขณะกำลังยกเลิกการแชร์ข้อมูล",
    "Error while changing permissions" : "เกิดข้อผิดพลาดขณะกำลังเปลี่ยนสิทธิ์การเข้าใช้งาน",
    "Shared with you and the group {group} by {owner}" : "ได้แชร์ให้กับคุณ และกลุ่ม {group} โดย {owner}",
    "Shared with you by {owner}" : "ถูกแชร์ให้กับคุณโดย {owner}",
    "Share with users or groups …" : "แชร์กับผู้ใช้หรือกลุ่ม ...",
    "Share with users, groups or remote users …" : "แชร์กับผู้ใช้หรือกลุ่มหรือผู้ใช้โดยการรีโมท ...",
    "Share link" : "แชร์ลิงค์",
    "The public link will expire no later than {days} days after it is created" : "ลิงค์สาธารณะจะหมดอายุภายใน {days} วัน หลังจากที่มันถูกสร้างขึ้น",
    "Link" : "ลิงค์",
    "Password protect" : "ป้องกันด้วยรหัสผ่าน",
    "Password" : "รหัสผ่าน",
    "Choose a password for the public link" : "เลือกรหัสผ่านสำหรับลิงค์สาธารณะ",
    "Allow editing" : "อนุญาตให้แก้ไข",
    "Email link to person" : "ส่งลิงก์ให้ทางอีเมล",
    "Send" : "ส่ง",
    "Set expiration date" : "กำหนดวันที่หมดอายุ",
    "Expiration" : "การหมดอายุ",
    "Expiration date" : "วันที่หมดอายุ",
    "Adding user..." : "กำลังเพิ่มผู้ใช้ ...",
    "group" : "กลุ่มผู้ใช้งาน",
    "remote" : "รีโมท",
    "Resharing is not allowed" : "ไม่อนุญาตให้แชร์ข้อมูลที่ซ้ำกัน",
    "Error while retrieving shares" : "ข้อผิดพลาดขณะดึงข้อมูลแชร์",
    "Unshare" : "ยกเลิกการแชร์",
    "notify by email" : "แจ้งเตือนทางอีเมล",
    "can share" : "สามารถแชร์ได้",
    "can edit" : "สามารถแก้ไข",
    "access control" : "ควบคุมการเข้าถึง",
    "create" : "สร้าง",
    "change" : "เปลี่ยนแปลง",
    "delete" : "ลบ",
    "Password protected" : "ใส่รหัสผ่านไว้",
    "Error unsetting expiration date" : "เกิดข้อผิดพลาดขณะยกเลิกการตั้งค่าวันที่หมดอายุ",
    "Error setting expiration date" : "เกิดข้อผิดพลาดในการตั้งค่าวันที่หมดอายุ",
    "Email sent" : "ส่งอีเมลแล้ว",
    "Warning" : "คำเตือน",
    "This share is password-protected" : "นี้แชร์การป้องกันด้วยรหัสผ่าน",
    "The password is wrong. Try again." : "รหัสผ่านที่ไม่ถูกต้อง กรุณาลองอีกครั้ง",
    "Sort by name" : "เรียงตามชื่อ",
    "Sort by date" : "เรียงตามวันที่",
    "Cancel upload" : "ยกเลิกการอัพโหลด",
    "Album information" : "ข้อมูลอัลบั้ม",
    "File list" : "รายชื่อไฟล์",
    "Sorry, this file could not be found." : "ขออภัยไม่พบไฟล์นี้",
    "Reasons might be:" : "เหตุผลอาจจะ:",
    "the wrong file ID was provided" : "ระบุไอดีไฟล์ผิด",
    "the file was removed" : "ไฟล์จะถูกลบออก",
    "the file is corrupt" : "ไฟล์เสียหาย",
    "the encryption key is missing" : "คีย์การเข้ารหัสหายไป",
    "Here is the error message returned by the server: " : "นี่คือข้อความผิดพลาดที่ส่งกลับโดยเซิร์ฟเวอร์:",
    "Sorry, but the server could not fulfill your request." : "ขออภัย แต่เซิร์ฟเวอร์ไม่สามารถตอบสนองการร้องขอของคุณ",
    "Possible reasons for the problem:" : "เหตุผลที่เป็นไปได้สำหรับปัญหา:",
    "a conflicting app was installed" : "แอพฯตรวจสอบปัญหาได้ถูกติดตั้งแล้ว",
    "a required component is missing or was disconnected" : "ส่วนประกอบที่จำเป็นขาดหายไปหรือถูกยกเลิกการเชื่อมต่อ",
    "the filesystem is not readable" : "ไม่สามารถอ่านระบบแฟ้ม",
    "Sorry, this link doesn't seem to work anymore." : "ขออภัย ลิงค์นี้ดูเหมือนจะมีปัญหา",
    "the item was removed" : "รายการที่ถูกลบออก",
    "the link has expired" : "ลิงค์หมดอายุ",
    "sharing is disabled" : "การแชร์ถูกปิดใช้งาน",
    "For more information, please ask the person who has sent you this link." : "สำหรับข้อมูลเพิ่มเติม โปรดถามคนที่ส่งลิงค์นี้ให้คุณ",
    "Picture view" : "ดูรูปภาพ",
    "New" : "ใหม่",
    "An error occured. Please try again" : "เกิดข้อผิดพลาด กรุณาลองอีกครั้ง",
    "Sending ..." : "กำลังส่ง..."
},
"nplurals=1; plural=0;");

==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/gallery/l10n/th.js <==
OC.L10N.register(
    "gallery",
    {
    "Gallery" : "แกลอรี่",
    "There was a problem reading files from this album" : "เกิดปัญหาการอ่านไฟล์จากอัลบั้มนี้",
    "Aborting preview. Could not find the file" : "กำลังยกเลิกการแสดงตัวอย่าง ไม่สามารถค้นหาไฟล์",
    "Could not move \"{file}\", target exists" : "ไม่สามารถย้ายไฟล์ \"{file}\" ไม่มีไฟล์นั้นอยู่",
    "Could not move \"{file}\"" : "ไม่สามารถย้ายไฟล์ \"{file}\"",
    "No compatible server found at {remote}" : "ไม่พบเซิร์ฟเวอร์ที่เข้ากันได้ที่ {ระยะไกล}",
    "Invalid server url" : "URL เซิร์ฟเวอร์ไม่ถูกต้อง",
    "Could not load the description" : "ไม่สามารถโหลดคำอธิบาย",
    "Could not load the description: " : "ไม่สามารถโหลดคำอธิบาย",
    "Copyright" : "ลิขสิทธิ์",
    "Could not load the copyright notice: " : "โปรดทราบไม่สามารถโหลดลิขสิทธิ์:",
    "Copyright notice" : "โปรดทราบเรื่องลิขสิทธิ์",
    "Link to copyright document" : "เชื่อมโยงไปยังเอกสารลิขสิทธิ์",
    "This application may not work properly on your browser." : "แอพฯนี้อาจทำงานผิดพลาดในเบราว์เซอร์ของคุณ",
    "For an improved experience, please install one of the following alternatives" : "เพื่อทางที่ดีขึ้นโปรดติดตั้งหนึ่งในทางเลือกดังต่อไปนี้",
    "Your browser is not supported!" : "เบราว์เซอร์ของคุณไม่ได้รับการสนับสนุน!",
    "please install one of the following alternatives" : "โปรดติดตั้งหนึ่งในทางเลือกดังต่อไปนี้",
    "Album cannot be shown" : "ไม่สามารถแสดงอัลบั้มได้",
    "No media files found" : "ไม่พบไฟล์สื่อ",
    "Upload new files via drag and drop or by using the [+] button above" : "อัพโหลดไฟล์ใหม่ผ่านการลากและวางหรือโดยการใช้ปุ่ม [+] ดังกล่าวข้างต้น",
    "Configuration error" : "กำหนดค่าผิดพลาด",
    "Hide Album" : "ซ่อนอัลบั้ม",
    "Could not hide album" : "ไม่สามารถซ่อนอัลบั้ม",
    "Error loading slideshow template" : "เกิดข้อผิดพลาดในการโหลดเทมเพลตสไลด์โชว์",
    "<strong>Error!</strong> Could not generate a preview of this file.<br>Please go to the next slide while we remove this image from the slideshow" : "<strong>ข้อผิดพลาด!</strong> ไม่สามารถสร้างตัวอย่างการแสดงของไฟล์นี้<br> โปรดไปยังภาพนิ่งถัดไปในขณะที่เราลบภาพนี้จากสไลด์โชว์",
    "Next" : "ถัดไป",
    "Play" : "เล่น",
    "Pause" : "หยุดชั่วคราว",
    "Previous" : "ก่อนหน้า",
    "Close" : "ปิด",
    "Download" : "ดาวน์โหลด",
    "Toggle background" : "สลับพื้นหลัง",
    "Delete" : "ลบ",
    "Share" : "แชร์",
    "Could not create file \"{file}\" because it already exists" : "ไม่สามารถสร้างไฟล์ \"{file}\" เพราะมันมีอยู่แล้ว",
    "Could not create file \"{file}\"" : "ไม่สามารถสร้างไฟล์ \"{file}\"",
    "\"{name}\" is an invalid file name." : "\"{name}\" เป็นชื่อไฟล์ที่ไม่ถูกต้อง",
    "File name cannot be empty." : "ชื่อไฟล์ไม่สามารถเว้นว่างได้",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" ไม่อนุญาตไฟล์ประเภทนี้",
    "Upload" : "อัพโหลด",
    "Error" : "ข้อผิดพลาด",
    "Error while sharing" : "เกิดข้อผิดพลาดขณะกำลังแชร์ข้อมูล",
    "Error while unsharing" : "เกิดข้อผิดพลาดขณะกำลังยกเลิกการแชร์ข้อมูล",
    "Error while changing permissions" : "เกิดข้อผิดพลาดขณะกำลังเปลี่ยนสิทธิ์การเข้าใช้งาน",
    "Shared with you and the group {group} by {owner}" : "ได้แชร์ให้กับคุณ และกลุ่ม {group} โดย {owner}",
    "Shared with you by {owner}" : "ถูกแชร์ให้กับคุณโดย {owner}",
    "Share with users or groups …" : "แชร์กับผู้ใช้หรือกลุ่ม ...",
    "Share with users, groups or remote users …" : "แชร์กับผู้ใช้หรือกลุ่มหรือผู้ใช้โดยการรีโมท ...",
    "Share link" : "แชร์ลิงค์",
    "The public link will expire no later than {days} days after it is created" : "ลิงค์สาธารณะจะหมดอายุภายใน {days} วัน หลังจากที่มันถูกสร้างขึ้น",
    "Link" : "ลิงค์",
    "Password protect" : "ป้องกันด้วยรหัสผ่าน",
    "Password" : "รหัสผ่าน",
    "Choose a password for the public link" : "เลือกรหัสผ่านสำหรับลิงค์สาธารณะ",
    "Allow editing" : "อนุญาตให้แก้ไข",
    "Email link to person" : "ส่งลิงก์ให้ทางอีเมล",
    "Send" : "ส่ง",
    "Set expiration date" : "กำหนดวันที่หมดอายุ",
    "Expiration" : "การหมดอายุ",
    "Expiration date" : "วันที่หมดอายุ",
    "No users or groups found for {search}" : "ไม่พบผู้ใช้หรือกลุ่มผู้ใช้ {search}",
    "No users found for {search}" : "ไม่พบผู้ใช้ {search}",
    "An error occurred (\"{message}\"). Please try again" : "เกิดข้อผิดพลาด (\"{message}\") กรุณาลองอีกครั้ง",
    "An error occurred. Please try again" : "เกิดข้อผิดพลาด กรุณาลองอีกครั้ง",
    "Adding user..." : "กำลังเพิ่มผู้ใช้ ...",
    "group" : "กลุ่มผู้ใช้งาน",
    "remote" : "รีโมท",
    "Resharing is not allowed" : "ไม่อนุญาตให้แชร์ข้อมูลที่ซ้ำกัน",
    "Error while retrieving shares" : "ข้อผิดพลาดขณะดึงข้อมูลแชร์",
    "Unshare" : "ยกเลิกการแชร์",
    "notify by email" : "แจ้งเตือนทางอีเมล",
    "can share" : "สามารถแชร์ได้",
    "can edit" : "สามารถแก้ไข",
    "access control" : "ควบคุมการเข้าถึง",
    "create" : "สร้าง",
    "change" : "เปลี่ยนแปลง",
    "delete" : "ลบ",
    "Password protected" : "ใส่รหัสผ่านไว้",
    "Error unsetting expiration date" : "เกิดข้อผิดพลาดขณะยกเลิกการตั้งค่าวันที่หมดอายุ",
    "Error setting expiration date" : "เกิดข้อผิดพลาดในการตั้งค่าวันที่หมดอายุ",
    "Sending…" : "กำลังส่ง....",
    "Email sent" : "ส่งอีเมลแล้ว",
    "Warning" : "คำเตือน",
    "Direct link" : "ลิ้งโดยตรง",
    "This share is password-protected" : "นี้แชร์การป้องกันด้วยรหัสผ่าน",
    "The password is wrong. Try again." : "รหัสผ่านที่ไม่ถูกต้อง กรุณาลองอีกครั้ง",
    "Sort by name" : "เรียงตามชื่อ",
    "Sort by date" : "เรียงตามวันที่",
    "Cancel upload" : "ยกเลิกการอัพโหลด",
    "Album information" : "ข้อมูลอัลบั้ม",
    "File list" : "รายชื่อไฟล์",
    "Sorry, this file could not be found." : "ขออภัยไม่พบไฟล์นี้",
    "Reasons might be:" : "เหตุผลอาจจะ:",
    "the wrong file ID was provided" : "ระบุไอดีไฟล์ผิด",
    "the file was removed" : "ไฟล์จะถูกลบออก",
    "the file is corrupt" : "ไฟล์เสียหาย",
    "the encryption key is missing" : "คีย์การเข้ารหัสหายไป",
    "Here is the error message returned by the server: " : "นี่คือข้อความผิดพลาดที่ส่งกลับโดยเซิร์ฟเวอร์:",
    "For more information, please contact your friendly Nextcloud administrator." : "สำหรับข้อมูลเพิ่มเติมกรุณาติดต่อผู้ดูแลระบบ Nextcloud ของคุณ",
    "Sorry, but the server could not fulfill your request." : "ขออภัย แต่เซิร์ฟเวอร์ไม่สามารถตอบสนองการร้องขอของคุณ",
    "Possible reasons for the problem:" : "เหตุผลที่เป็นไปได้สำหรับปัญหา:",
    "a conflicting app was installed" : "แอพฯตรวจสอบปัญหาได้ถูกติดตั้งแล้ว",
    "a required component is missing or was disconnected" : "ส่วนประกอบที่จำเป็นขาดหายไปหรือถูกยกเลิกการเชื่อมต่อ",
    "the filesystem is not readable" : "ไม่สามารถอ่านระบบแฟ้ม",
    "Sorry, this link doesn't seem to work anymore." : "ขออภัย ลิงค์นี้ดูเหมือนจะมีปัญหา",
    "the item was removed" : "รายการที่ถูกลบออก",
    "the link has expired" : "ลิงค์หมดอายุ",
    "sharing is disabled" : "การแชร์ถูกปิดใช้งาน",
    "For more information, please ask the person who has sent you this link." : "สำหรับข้อมูลเพิ่มเติม โปรดถามคนที่ส่งลิงค์นี้ให้คุณ",
    "Picture view" : "ดูรูปภาพ",
    "New" : "ใหม่"
},
"nplurals=1; plural=0;");
